@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use autodie qw( :all );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use App::CISetup::Types qw( Path );
 use Try::Tiny;
@@ -14,7 +14,9 @@ use YAML qw( Dump LoadFile );
 use Moose::Role;
 
 requires qw(
+    _cisetup_flags
     _create_config
+    _fix_up_yaml
     _update_config
 );
 
@@ -28,10 +30,7 @@ has file => (
 sub create_file {
     my $self = shift;
 
-    my $yaml = $self->_create_config;
-
-    my $file = $self->file;
-    $file->spew($yaml);
+    $self->file->spew( $self->_config_to_yaml( $self->_create_config ) );
 
     return;
 }
@@ -51,7 +50,9 @@ sub update_file {
 
     return 0 unless $content;
 
-    my $yaml = $self->_update_config($content);
+    my $config = $self->_update_config($content);
+    my $yaml   = $self->_config_to_yaml($config);
+
     return 0 if $yaml eq $orig;
 
     $file->spew($yaml);
@@ -59,6 +60,39 @@ sub update_file {
     return 1;
 }
 
+sub _config_to_yaml {
+    my $self   = shift;
+    my $config = shift;
+
+    ## no critic (TestingAndDebugging::ProhibitNoWarnings, Variables::ProhibitPackageVars)
+    no warnings 'once';
+
+    # If Perl versions aren't quotes then Travis displays 5.10 as "5.1"
+    local $YAML::QuoteNumericStrings = 1;
+    my $yaml = Dump($config);
+    $yaml = $self->_fix_up_yaml($yaml);
+
+    return $self->_fix_up_yaml($yaml) . $self->_cisetup_flags_as_comment;
+}
+
+sub _cisetup_flags_as_comment {
+    my $self = shift;
+
+    my $yaml = Dump( $self->_cisetup_flags );
+    $yaml =~ s/^/# /gm;
+
+    # Yes, this is YAML embedded in YAML as a comment. Yes, this is dumb. Yes,
+    # this is necessary. Unfortunately, AppVeyor chokes on random keys in its
+    # config file, so we have no choice but to use a comment. We could use
+    # Data::Dumper but we're already using YAML, and I don't really love doing
+    # an "eval" when trying to read this data.
+    return sprintf( <<'EOF', $yaml );
+### __app_cisetup__
+%s
+### __app_cisetup__
+EOF
+}
+
 ## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _reorder_yaml_blocks {
     my $self         = shift;
